{-------------------------------------------------------------}
{           CartaVox - configurador
{-------------------------------------------------------------}

unit carConf;

interface

uses
    dvcrt,
    dvForm,
    dvWin,
    classes,
    sysUtils,
    windows,
    carDecod,
    carMsg,
    carSMTP,
    carTela,
    carUtil,
    carVars;

procedure recuperaConfig;
procedure configuraTudo;
procedure configurar;
procedure pegaConfigInicial;
procedure recuperaConfigGrupoContas (contaGrupo: string);
function primeiraLetra (s: string): char;
procedure formConfig;

implementation

const
    numChaves = 33;
    tabChaves: array [1..numChaves] of pchar = (
        'SERVIDORSMTP',
        'SMTPCOMSENHA',
        'SMTPCOMTLS',
        'PORTASMTP',
        'SERVIDORPOP3',
        'USASSL',
        'PORTAPOP3',
        'SERVIDORIMAP',
        'ENDERRESPOSTA',
        'ENDERUSUARIO',
        'CONTAUSUARIO',
        'NOMEUSUARIO',
        'DIRRECEBE',
        'DIRENVIA',
        'DIRANEXO',
        'LIMITEAUTOREC',
        'ASSINATURA',
        'APELIDOS',
        'COPIAENVIADAS',
        'ARMAZENASENHA',
        'SCCV',
        'SCCVSMTP',
        'SCCVPOP3',
        'APLICARREGRAS',
        'INSERIRASSINATURA',
        'INSERIRCONFIRMACAOLEITURA',
        'TEMPOREMONITORAR',
        'AVISANOVASNOMONITORAR',
        'RECEBERAUTONOMONITORAR',
        'ARQRESPAUT',
        'ASSRESPAUT',
        'SIGRESPAUT',
        'GRUPODECONTAS'
    );

{-------------------------------------------------------------}
{       Simplifica o nome da function pegaTextoMensagem de carMsg.pas
{-------------------------------------------------------------}

function ms (s: string): string;
begin
    ms := pegaTextoMensagem(s);
end;

{-------------------------------------------------------------}
{       consiste nomes de diretrios e arquivos da configurao
{-------------------------------------------------------------}

procedure consisteDirArq;
var erro: boolean;
    c, c2: char;
begin
    erro := false;
    if not existeDir (dirRecebe) then
        begin
            mensagem ('CTERDREC', 1);  {'Diretrio de recepo de cartas inexistente'}
            mensagem ('CTPOSCRI', 0);  {'Posso cri-lo? '}
            sintLeTecla (c, c2);
            writeln;
            if upcase(c) = 'N' then
                erro := true
            else
                begin
                     {$I-}  mkdir (dirRecebe);  {$I+}
                     if ioresult <> 0 then
                         begin
                             erro := true;
                             mensagem ('CTDRNCRI', 2);  {'Diretrio de recepo no foi criado.'}
                         end;
                end;
        end;

    if erro then
         mensagem ('CTNESQCR', 0);  {'No esqueca de criar o diretrio antes de receber ou enviar cartas.'}

    erro := false;
    if not existeDir (dirEnvia) then
        begin
            mensagem ('CTERDENV', 1);  {'Diretrio para cartas a enviar inexistente'}
            mensagem ('CTPOSCRI', 0);  {'Posso cri-lo? '}
            sintLeTecla (c, c2);
            writeln;
            if upcase(c) = 'N' then
                erro := true
            else
                begin
                     {$I-}  mkdir (dirEnvia);  {$I+}
                     if ioresult <> 0 then
                         begin
                             erro := true;
                             mensagem ('CTDENCRI', 2);  {'Diretrio de envio no foi criado.'}
                         end;
                end;
        end;

    if erro then
         mensagem ('CTNESQCR', 0);  {'No esqueca de criar o diretrio antes de receber ou enviar cartas.'}

    if (nomeAssinatura <> '') and (not fileExists (nomeAssinatura)) then
        mensagem ('CTEDIASS', 1);   {'Arquivo de assinatura no existe, no se esquea de edit-lo.'}

    if (nomeArqspams<> '') and (not fileExists (nomeArqspams)) then
        mensagem ('CTEDISPM', 1);   {'Arquivo de spams no existe, no se esquea de edit-lo.'}
end;

{-------------------------------------------------------------}
{       configura programa
{-------------------------------------------------------------}

procedure configuraTudo;
var
    s, contaUsuarioAntigo: string;
    c: char;
    sz, szConfig: array [0..144] of char;

label deNovo;

begin
//    transmitirPreparadas; //Pergunta se transmite caso exista
    clrscr;
    textBackground (BLUE);
    writeln (CONF_CARTAVOX);   {'CARTAVOX - Configurao'}
    textBackground (BLACK);
    writeln;

    contaUsuarioAntigo := contaUsuario;

    repeat
        formCria;
        formCampo     ('CT_POP3',  ms('CT_POP3'),   hostPOP3, 60);        {'Nome do servidor POP3'}
        formCampoInt  ('CT_PPOP3', ms('CT_PPOP3'),  portaPOP3);           {'Porta POP3'}
        formCampoBool ('CT_SSL',   ms('CT_SSL'),    usaSSL);              {'Usa segurana SSL'}

        formCampo     ('CT_SMTP',  ms('CT_SMTP'),   hostSMTP, 60);        {'Nome do servidor SMTP'}
        formCampoInt  ('CT_PSMTP', ms('CT_PSMTP'),  portaSMTP);           {'Porta SMTP'}
        formCampoBool ('CT_SENHA', ms('CT_SENHA'),  smtpComSenha);        {'SMTP opera com senha'}
        formCampoBool ('CT_TLS',   ms('CT_TLS'),    smtpComTLS);          {'SMTP com segurana TLS'}
        formCampoBool ('CT_SMSSL', ms('CT_SMSSL'),  smtpComSSL);          {'SMTP com segurana SSL'}    //*** Antonio
        formCampoBool ('CT_SMTLS',   ms('CT_SMTLS'),    smtpComTLS);          {'SMTP exige segurana TLS'}

        formCampo     ('CT_IMAP',  ms('CT_IMAP'),   hostIMAP, 60);        {'Nome do servidor IMAP'}
        formCampoBool ('CT_IMAPSSL',   ms('CT_IMAPSSL'),    IMAPUsaSSL); {'IMAP exige segurana'}

    formCampo     ('CT_NOME',  ms('CT_NOME'),   nomeUsuario, 60);     {'Nome registrado como'}
    formCampo     ('CT_RESP',  ms('CT_RESP'),   enderResposta, 60);   {'Endereo para resposta'}
    formCampo     ('CT_ENDER', ms('CT_ENDER'),  enderUsuario, 60);    {'Endereo eletrnico'}
    formCampo     ('CT_CONTA', ms('CT_CONTA'),  contaUsuario, 60);    {'Conta no servidor'}
    formCampo     ('CT_DIRRC', ms('CT_DIRRC'),  dirRecebe, 50);       {'Diretrio cartas recebidas'}
    formCampo     ('CT_DIREN', ms('CT_DIREN'),  dirEnvia, 50);        {'Diretrio cartas a enviar'}
    formCampoInt  ('CT_LIMRC', ms('CT_LIMRC'),  maxTamAuto);          {'Limite carta recebida'}
    formCampo     ('CT_ARQAS', ms('CT_ARQAS'),  nomeAssinatura, 50);  {'Arquivo de assinatura'}
    formCampo     ('CT_ARQAP', ms('CT_ARQAP'),  nomeArqApelidos, 50); {'Arquivo de apelidos'}
    formCampo     ('CT_ARQSP', ms('CT_ARQSP'),  nomeArqspams, 50); {'Arquivo de spams'}
    formCampoBool ('CT_GUARD', ms('CT_GUARD'),  guardaEnviadas);      {'Guardar cartas enviadas'}
    formCampoBool ('CT_GSENH', ms('CT_GSENH'),  guardaSenha);    {'Guardar a senha'}
        formCampoBool ('CT_APREG', ms('CT_APREG'),  aplicRegras);         {'Aplicar regras'}
        formCampoBool ('CT_INASS', ms('CT_INASS'),  inserirAssinatura); {'Inserir assinatura'}
        formCampoBool ('CT_INCOR', ms('CT_INCOR'),  inserirConfRec); {'Confirmar recebimento'}
        formCampo     ('CT_DIRAN', ms('CT_DIRAN'),  dirAnexo, 50);        {'Diretrio para anexos'}

        c := formEdita (true);
    until c = ESC;

    consisteDirArq;

    strPCopy (sz, hostIMAP);
    writePrivateProfileString('CARTAVOX', 'SERVIDORIMAP', sz, 'DOSVOX.INI');
    strPCopy (sz, hostSMTP);
    writePrivateProfileString('CARTAVOX', 'SERVIDORSMTP', sz, 'DOSVOX.INI');
    strPCopy (sz, hostPOP3);
    writePrivateProfileString('CARTAVOX', 'SERVIDORPOP3', sz, 'DOSVOX.INI');
    strPCopy (sz, nomeUsuario);
    writePrivateProfileString('CARTAVOX', 'NOMEUSUARIO',  sz, 'DOSVOX.INI');
    strPCopy (sz, enderResposta);
    writePrivateProfileString('CARTAVOX', 'ENDERRESPOSTA', sz, 'DOSVOX.INI');
    strPCopy (sz, enderUsuario);
    writePrivateProfileString('CARTAVOX', 'ENDERUSUARIO', sz, 'DOSVOX.INI');
    strPCopy (sz, contaUsuario);
    writePrivateProfileString('CARTAVOX', 'CONTAUSUARIO', sz, 'DOSVOX.INI');
    strPCopy (sz, dirRecebe);
    writePrivateProfileString('CARTAVOX', 'DIRRECEBE',    sz, 'DOSVOX.INI');
    strPCopy (sz, dirEnvia);
    writePrivateProfileString('CARTAVOX', 'DIRENVIA',     sz, 'DOSVOX.INI');
    strPCopy (sz, dirAnexo);
    writePrivateProfileString('CARTAVOX', 'DIRANEXO',     sz, 'DOSVOX.INI');
    str (maxTamAuto, s);
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'LIMITEAUTOREC',sz, 'DOSVOX.INI');
    strPCopy (sz, nomeAssinatura);
    writePrivateProfileString('CARTAVOX', 'ASSINATURA',   sz, 'DOSVOX.INI');
    strPCopy (sz, nomeArqspams);
    writePrivateProfileString('CARTAVOX', 'ARQBLOQUEADOS', sz, 'DOSVOX.INI');
    writePrivateProfileString('MATASPAM', 'ARQBLOQUEADOS',   sz, 'DOSVOX.INI');
    strPCopy (sz, nomeArqApelidos);
    writePrivateProfileString('CARTAVOX', 'APELIDOS',   sz, 'DOSVOX.INI');
    if guardaEnviadas then
        writePrivateProfileString('CARTAVOX', 'COPIAENVIADAS', 'SIM', 'DOSVOX.INI')
    else
        writePrivateProfileString('CARTAVOX', 'COPIAENVIADAS', 'NAO', 'DOSVOX.INI');
    if usaSSL then
        writePrivateProfileString('CARTAVOX', 'USASSL', 'SIM', 'DOSVOX.INI')
    else
        writePrivateProfileString('CARTAVOX', 'USASSL', 'NAO', 'DOSVOX.INI');
    if guardaSenha then
        begin
            writePrivateProfileString('CARTAVOX', 'ARMAZENASENHA', 'SIM', 'DOSVOX.INI');
            strPCopy (szConfig, nomeConfiguracao);
            writePrivateProfileString(szConfig, 'ARMAZENASENHA', 'SIM', 'CARTAVOX.INI');
            if contaUsuarioAntigo = contaUsuario then
                begin
                    strPCopy (sz, codFraseMime64 (senhaSalvaSmtp));
                    writePrivateProfileString('CARTAVOX', 'SCCV', sz, 'DOSVOX.INI');
                    writePrivateProfileString('CARTAVOX', 'SCCVSMTP', sz, 'DOSVOX.INI');
                    writePrivateProfileString(szConfig, 'SCCV', sz, 'CARTAVOX.INI');
                    writePrivateProfileString(szConfig, 'SCCVSMTP', sz, 'CARTAVOX.INI');
    strPCopy (sz, nomeArqspams);
    writePrivateProfileString(szConfig, 'ARQBLOQUEADOS', sz, 'CARTAVOX.INI');
                end;
        end
    else
        begin
            writePrivateProfileString('CARTAVOX', 'ARMAZENASENHA', 'NAO', 'DOSVOX.INI');
            writePrivateProfileString('CARTAVOX', 'SCCV', NIL, 'DOSVOX.INI');
            writePrivateProfileString('CARTAVOX', 'SCCVSMTP', NIL, 'DOSVOX.INI');
            strPCopy (szConfig, nomeConfiguracao);
            writePrivateProfileString(szConfig, 'ARMAZENASENHA', 'NAO', 'CARTAVOX.INI');
            writePrivateProfileString(szConfig, 'SCCV', NIL, 'CARTAVOX.INI');
            writePrivateProfileString(szConfig, 'SCCVSMTP', NIL, 'CARTAVOX.INI');
        end;

    if aplicRegras then
        writePrivateProfileString('CARTAVOX', 'APLICARREGRAS', 'SIM', 'DOSVOX.INI')
        else
        writePrivateProfileString('CARTAVOX', 'APLICARREGRAS', 'NO', 'DOSVOX.INI');

    if inserirAssinatura then
        writePrivateProfileString('CARTAVOX', 'INSERIRASSINATURA', 'SIM', 'DOSVOX.INI')
        else
        writePrivateProfileString('CARTAVOX', 'INSERIRASSINATURA', 'NO', 'DOSVOX.INI');

    if inserirConfRec then
        writePrivateProfileString('CARTAVOX', 'INSERIRCONFIRMACAOLEITURA', 'SIM', 'DOSVOX.INI')
        else
        writePrivateProfileString('CARTAVOX', 'INSERIRCONFIRMACAOLEITURA', 'NO', 'DOSVOX.INI');

    if smtpComSenha then
        writePrivateProfileString('CARTAVOX', 'SMTPCOMSENHA',  'SIM', 'DOSVOX.INI')
    else
        writePrivateProfileString('CARTAVOX', 'SMTPCOMSENHA',  'NAO', 'DOSVOX.INI');

    if smtpComTLS then
        writePrivateProfileString('CARTAVOX', 'SMTPCOMTLS',  'SIM', 'DOSVOX.INI')
    else
        writePrivateProfileString('CARTAVOX', 'SMTPCOMTLS',  'NAO', 'DOSVOX.INI');

    if portaSMTP = 0 then
        if usaSSL and (not smtpComTLS) then
            portaSMTP := 465
        else
            portaSMTP := 25;
    str (portaSMTP, s);
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'PORTASMTP', sz, 'DOSVOX.INI');

    if portaPOP3 = 0 then
        if not usaSSL then
            portaPOP3 := 995
        else
            portaPOP3 := 110;
    str (portaPOP3, s);
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'PORTAPOP3', sz, 'DOSVOX.INI');

    if guardaSenha then
        begin
            writePrivateProfileString('CARTAVOX', 'ARMAZENASENHA', 'SIM', 'DOSVOX.INI');
            strPCopy (szConfig, nomeConfiguracao);
            writePrivateProfileString(szConfig, 'ARMAZENASENHA', 'SIM', 'CARTAVOX.INI');
            if contaUsuarioAntigo = contaUsuario then
                begin
                    strPCopy (sz, codFraseMime64 (senhaSalvaPop3));
                    writePrivateProfileString('CARTAVOX', 'SCCVPOP3', sz, 'DOSVOX.INI');
                    writePrivateProfileString(szConfig, 'SCCVPOP3', sz, 'CARTAVOX.INI');
                end;
        end
    else
        begin
            writePrivateProfileString('CARTAVOX', 'ARMAZENASENHA', 'NAO', 'DOSVOX.INI');
            writePrivateProfileString('CARTAVOX', 'SCCVPOP3', NIL, 'DOSVOX.INI');
            strPCopy (szConfig, nomeConfiguracao);
            writePrivateProfileString(szConfig, 'ARMAZENASENHA', 'NAO', 'CARTAVOX.INI');
            writePrivateProfileString(szConfig, 'SCCVPOP3', NIL, 'CARTAVOX.INI');
        end;
    if smtpComSenha then
        writePrivateProfileString('CARTAVOX', 'SMTPCOMSENHA',  'SIM', 'DOSVOX.INI')
    else
        writePrivateProfileString('CARTAVOX', 'SMTPCOMSENHA',  'NAO', 'DOSVOX.INI');

    while keypressed do readkey;
    mensagem ('CTFIMCNF', 2);   {'Fim da configurao'}
end;

{-------------------------------------------------------------}
{       configura monitoramento
{-------------------------------------------------------------}

procedure configuraMonitoramento;
var
    s: string;
    sz: array [0..144] of char;

label deNovo;
begin
    clrscr;
    textBackground (BLUE);
    writeln (CONFMONIT_CARTAVOX);   {'CARTAVOX - Configurao do monitoramento'}
    textBackground (BLACK);
    writeln;

    formCria;
    formCampoInt  ('CTINTERV', ms('CTINTERV'),  tempoRemonitorar);          {'Aps quantos segundos remonitoro (sugiro 60)? '}
    formCampoBool ('CTAVINOV', ms('CTAVINOV'),  avisaNovasMonitorar); {'Aviso s quando chegarem cartas novas? '}
    formCampoBool ('CTRECAUT', ms('CTRECAUT'),  receberaAutMonitorar); { 'Deseja receber as cartas automaticamente: '}
    formEdita (true);

    consisteDirArq;

    str (tempoRemonitorar, s);
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'TEMPOREMONITORAR',sz, 'DOSVOX.INI');

    if avisaNovasMonitorar then
        writePrivateProfileString('CARTAVOX', 'AVISANOVASNOMONITORAR', 'SIM', 'DOSVOX.INI')
        else
        writePrivateProfileString('CARTAVOX', 'AVISANOVASNOMONITORAR', 'NO', 'DOSVOX.INI');

    if receberaAutMonitorar then
        writePrivateProfileString('CARTAVOX', 'RECEBERAUTONOMONITORAR', 'SIM', 'DOSVOX.INI')
        else
        writePrivateProfileString('CARTAVOX', 'RECEBERAUTONOMONITORAR', 'NO', 'DOSVOX.INI');

    while keypressed do readkey;
    mensagem ('CTFIMCNF', 2);   {'Fim da configurao'}
end;

{-------------------------------------------------------------}
{       Outras configuraes - Itens que no aparecem na procedure configuraTudo
{-------------------------------------------------------------}

procedure outrasConfiguracoes;
var
    s: string;
    sz: array [0..144] of char;

label deNovo;
begin
    clrscr;
    textBackground (BLUE);
    writeln (CONFAVAN_CARTAVOX); {'CARTAVOX - Configurao avanada';}
    writeln;

    formCria;
    formCampoBool ('CT_FALNP', ms('CT_FALNP'), falaNomePrimeiro); {'Falar nome antes do assunto'}
    formCampoBool ('CT_ORDEN', ms('CT_ORDEN'), ordenarDataEnvio); {'Ordenar por data de envio'}
    formCampoBool ('CT_CAORD', ms('CT_CAORD'), ordemInversa); {'Folhear em ordem decrescente'}
    formCampoBool ('CT_CLEK', ms('CT_CLEK'), clek); {'Sonorizar na recepo e transmio'}
    formCampoBool ('CT_PERSA', ms('CT_PERSA'), perguntaAoSair); {'Perguntar ao sair'}
    formCampoBool ('CT_PERSF', ms('CT_PERSF'), perguntaAoSairFolheamento); {'Perguntar ao sair do folheamento'}
    formCampoBool ('CT_CABRE', ms('CT_CABRE'), cabecalhoResumido); {'Cabealho resumido na resposta'}
    formCampoBool ('CT_AUDUL', ms('CT_AUDUL'), autoEnviaDuplicadasLixeira); {Enviar duplicadas automaticamente para lixeira'}
    formCampoBool ('CT_ADIOR', ms('CT_ADIOR'), adicionaOriginal); {'Adicionar original na cpia'}
    formCampo ('CT_DIRLI', ms('CT_DIRLI'), dirLixeira, 50); {'Diretrio da lixeira'}

    formEdita (true);

    consisteDirArq;

    if falaNomePrimeiro then s := 'SIM'
    else s := 'NO';
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'FALANOMEPRIMEIRO', sz, 'DOSVOX.INI');

    if ordenarDataEnvio then s := 'SIM'
    else s := 'NO';
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'ORDENARDATAENVIO', sz, 'DOSVOX.INI');

    if ordemInversa then s := 'SIM'
    else s := 'NO';
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'ORDEMINVERSA', sz, 'DOSVOX.INI');

    if clek then s := 'SIM'
    else s := 'NO';
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'CLEK', sz, 'DOSVOX.INI');

    if perguntaAoSair then s := 'SIM'
    else s := 'NO';
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'PERGUNTAAOSAIR', sz, 'DOSVOX.INI');

    if perguntaAoSairFolheamento then s := 'SIM'
    else s := 'NO';
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'PERGUNTAAOSAIRFOLHEAMENTO', sz, 'DOSVOX.INI');

    if cabecalhoResumido then s := 'SIM'
    else s := 'NO';
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'CABECALHORESUMIDO', sz, 'DOSVOX.INI');

    if autoEnviaDuplicadasLixeira then s := 'SIM'
    else s := 'NO';
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'AUTOENVIADUPLICADASLIXEIRA', sz, 'DOSVOX.INI');

    if adicionaOriginal then s := 'SIM'
    else s := 'NO';
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'ADICIONAORIGINAL', sz, 'DOSVOX.INI');

    dirLixeira := sintAmbiente ('CARTAVOX', 'DIRLIXEIRA');
    if (dirLixeira = '') or (not existeDir (dirLixeira))  then dirLixeira := sintAmbiente ('DOSVOX', 'DIRLIXEIRA');
    strPCopy (sz, dirLixeira);
    writePrivateProfileString('CARTAVOX', 'DIRLIXEIRA', sz, 'DOSVOX.INI');

    while keypressed do readkey;
    mensagem ('CTFIMCNF', 2);   {'Fim da configurao'}
end;

function primeiraLetra (s: string): char;
begin
    s := trim (s);
    delete (s, 2, 999);
    if s = '' then primeiraLetra := ' '
              else primeiraLetra := upcase (s[1]);
end;

{-------------------------------------------------------------}
{           Configura velocidade e voz Sapi
{-------------------------------------------------------------}

procedure formConfig;
var velGeral: integer;
    confSapi: shortString;
    confTipoSapi, confNum, confVeloc, confTonal, erro: integer;
    parm: array [0..255] of char;
    i: integer;
    s: string;
begin

    //Recuperando informaes do DOSVOX.INI

    val (sintAmbiente('CARTAVOX', 'VELOCIDADE'), velGeral, erro);
    if erro <> 0 then velGeral := 0;

    confSapi       := (sintAmbiente('CARTAVOX', 'SAPIATIVADO'));

    val (sintAmbiente('CARTAVOX', 'TIPOSAPI'), confTipoSapi, erro);
    if erro <> 0 then val (sintAmbiente('SERVFALA', 'TIPOSAPI'), confTipoSapi, erro);
    if erro <> 0 then confTipoSapi := 4;

    val (sintAmbiente('CARTAVOX', 'NUMEROSAPI'), confNum, erro);
    if erro <> 0 then confNum:= 1;
    val (sintAmbiente('CARTAVOX', 'VELOCIDADESAPI'), confVeloc, erro);
    if erro <> 0 then confVeloc:= 0;
    val (sintAmbiente('CARTAVOX', 'TONALIDADESAPI'), confTonal, erro);
    if erro <> 0 then confTonal:= 0;

    // Apresentando o formulrio

    textBackground (BLUE);
    writeln;
    mensagem ('CTPAICON', 0);  {'Painel de Configurao'}
    sintBip; sintBip;
    textBackground (BLACK);
    for i := 10 to 25 do
        begin
             gotoxy (1, i);  clreol;
        end;
    gotoxy (1, 13);

    formCria;
    tamRotulosForm := 35;
    formCampoInt ('CTVELC',   ms('CTVELC')   {'Velocidade: '},         velGeral); {''}
    formCampo    ('CTCOMSAP', ms('CTCOMSAP') {'Com SAPI: '},           confSapi, 4); {''}
    formCampoInt ('CTTIPSAP', ms('CTTIPSAP') {'Tipo SAPI (4 ou 5): '}, confTipoSapi); {''}
    formCampoInt ('CTNUMSAP', ms('CTNUMSAP') {'Nmero SAPI: '},        confNum); {''}
    formCampoInt ('CTVEL',    ms('CTVEL')    {'Velocidade SAPI: '},    confVeloc); {''}
    formCampoInt ('CTTOM',    ms('CTTOM')    {'Tonalidade SAPI: '},    confTonal); {''}
    formEdita (true);

    //Efetuando modificaes

    if (velGeral < 0) or (velGeral > 5) then
        velGeral:= 0;

    // gravando DOSVOX.INI

    writePrivateProfileString ('CARTAVOX', 'VELOCIDADE', pchar(intToStr(velGeral)), 'DOSVOX.INI');
    strpCopy (parm, maiuscAnsi(confSapi));
    writePrivateProfileString ('CARTAVOX', 'SAPIATIVADO', (parm), 'DOSVOX.INI');
    writePrivateProfileString ('CARTAVOX', 'TIPOSAPI', pchar(intToStr(confTipoSapi)), 'DOSVOX.INI');
    writePrivateProfileString ('CARTAVOX', 'NUMEROSAPI', pchar(intToStr(confNum)), 'DOSVOX.INI');
    writePrivateProfileString ('CARTAVOX', 'VELOCIDADESAPI', pchar(intToStr(confVeloc)), 'DOSVOX.INI');
    writePrivateProfileString ('CARTAVOX', 'TONALIDADESAPI', pchar(intToStr(confTonal)), 'DOSVOX.INI');

    mensagem ('CTAGUARC', 0);  {'Aguarde, configurando'}
    sintPara;

//neno
    s := sintAmbiente ('CARTAVOX', 'VELOCIDADE');
    if (s = '') or (s = '0') then
        s := sintAmbiente ('TRADUTOR', 'VELOCIDADE');
    if s = '' then
        velGeral := 0
    else
        val (s, velGeral, erro);

    if confSapi = '' then
        begin
            comSapi := primeiraLetra (sintAmbiente ('TRADUTOR', 'SAPI')) = 'S';
            if comSapi then
                begin
                    val (sintAmbiente('SERVFALA', 'VOZ'), confNum, erro);
                    if erro <> 0 then val (sintAmbiente('CARTAVOX', 'NUMEROSAPI'), confNum, erro);
                    if erro <> 0 then confNum := 1;

                    val (sintAmbiente('SERVFALA', 'TIPOSAPI'), confTipoSapi, erro);
                    if erro <> 0 then val (sintAmbiente('CARTAVOX', 'TIPOSAPI'), confTipoSapi, erro);
                    if erro <> 0 then confTipoSapi := 3;

                    val (sintAmbiente('SERVFALA', 'VELOCIDADESAPI'), confVeloc, erro);
                    if erro <> 0 then val (sintAmbiente('CARTAVOX', 'VELOCIDADESAPI'), confVeloc, erro);
                    if erro <> 0 then confVeloc:= 0;

                    val (sintAmbiente('SERVFALA', 'TONALIDADESAPI'), confTonal, erro);
                    if erro <> 0 then val (sintAmbiente('CARTAVOX', 'TONALIDADESAPI'), confTonal, erro);
                    if erro <> 0 then confTonal:= 0;

                    sintReinic (velGeral, comSapi, confTipoSapi, confNum, confVeloc, confTonal);
                end;
        end
    else
        begin
            comSapi := primeiraLetra (confSapi) = 'S';
            sintReinic (velGeral, comSapi, confTipoSapi, confNum, confVeloc, confTonal);
        end;

    writeln;
    mensagem ('CTOK', 0);  {'Ok'}
    sintBip; sintBip; sintBip;
end;

{-------------------------------------------------------------}
{           pega configurao inicial
{-------------------------------------------------------------}

procedure pegaConfigInicial;
var s: string;
    erro: integer;
    sz: array [0..144] of char;
begin
    agruparPorAssunto := false;

    SOWindows := sintAmbiente ('DOSVOX', 'WINDOWS') <> '';

    nomeConfiguracao := sintAmbiente ('CARTAVOX', 'CONFIGURACAO');
    setWindowTitle ('CARTAVOX ' + nomeConfiguracao);
    criaPrefixoNomeArq;

    hostIMAP     := sintAmbiente ('CARTAVOX', 'SERVIDORIMAP');
    hostSMTP     := sintAmbiente ('CARTAVOX', 'SERVIDORSMTP');
    hostPOP3     := sintAmbiente ('CARTAVOX', 'SERVIDORPOP3');
    nomeUsuario  := sintAmbiente ('CARTAVOX', 'NOMEUSUARIO');
    enderUsuario := sintAmbiente ('CARTAVOX', 'ENDERUSUARIO');
    enderResposta := sintAmbiente ('CARTAVOX', 'ENDERRESPOSTA');
    contaUsuario := sintAmbiente ('CARTAVOX', 'CONTAUSUARIO');
    dirRecebe    := sintAmbiente ('CARTAVOX', 'DIRRECEBE');
    dirEnvia     := sintAmbiente ('CARTAVOX', 'DIRENVIA');
    dirLixeira := sintAmbiente ('CARTAVOX', 'DIRLIXEIRA');
    if (dirLixeira = '') or (not existeDir (dirLixeira))  then dirLixeira := sintAmbiente ('DOSVOX', 'DIRLIXEIRA');

    dirAnexo := sintAmbiente ('CARTAVOX', 'DIRANEXO');
    if (dirAnexo <> '') and (dirAnexo[length(dirAnexo)] in ['\', '/']) then
        delete (dirAnexo, length(dirAnexo), 1);

    nomeArqApelidos := sintAmbiente ('CARTAVOX', 'APELIDOS');
    if nomeArqApelidos = '' then
        begin
            nomeArqApelidos := 'c:\winvox\apelidos.ini';
            strPCopy (sz, nomeArqApelidos);
            writePrivateProfileString('CARTAVOX', 'APELIDOS',     sz, 'DOSVOX.INI');
        end;

    s := sintAmbiente ('CARTAVOX', 'ANTIGONOMEARQ');
    if s = '' then
        begin
            antigoNomeArq := FALSE;
            strPCopy (sz, 'NAO');
            writePrivateProfileString('CARTAVOX', 'ANTIGONOMEARQ',     sz, 'DOSVOX.INI');
        end
    else
        antigoNomeArq := upcase (s[1]) = 'S';

    s := sintAmbiente ('CARTAVOX', 'ORDENARDATAENVIO');
    if s = '' then
        begin
            ordenarDataEnvio := FALSE;
            strPCopy (sz, 'NAO');
            writePrivateProfileString('CARTAVOX', 'ORDENARDATAENVIO',     sz, 'DOSVOX.INI');
        end
    else
        ordenarDataEnvio := upcase (s[1]) = 'S';

    s := sintAmbiente ('CARTAVOX', 'ORDEMINVERSA');
    if s = '' then
        begin
            ordemInversa := FALSE;
            strPCopy (sz, 'NAO');
            writePrivateProfileString('CARTAVOX', 'ORDEMINVERSA',     sz, 'DOSVOX.INI');
        end
    else
        ordemInversa := upcase (s[1]) = 'S';

    s := sintAmbiente ('CARTAVOX', 'USASSL');
    if s = '' then
        begin
            usaSSL := FALSE;
            strPCopy (sz, 'NAO');
            writePrivateProfileString('CARTAVOX', 'USASSL',     sz, 'DOSVOX.INI');
        end
    else
    if upcase (s[1]) = 'S' then
        usaSSL := TRUE
    else
        usaSSL := FALSE;

    s := sintAmbiente ('CARTAVOX', 'IMAPUSASSL');
    if s = '' then
        IMAPUsaSSL := usaSSL
    else
        IMAPUsaSSL := upcase (s[1]) = 'S';

    s := sintAmbiente ('CARTAVOX', 'AUTOENVIADUPLICADASLIXEIRA');
    if s = '' then
        begin
            autoEnviaDuplicadasLixeira := FALSE;
            strPCopy (sz, 'NAO');
            writePrivateProfileString('CARTAVOX', 'AUTOENVIADUPLICADASLIXEIRA',     sz, 'DOSVOX.INI');
        end
    else
        autoEnviaDuplicadasLixeira := upcase (s[1]) = 'S';

    s := sintAmbiente ('CARTAVOX', 'LIMITEAUTOREC');
    if s <> '' then
        val (s, maxTamAuto, erro);
    if (erro > 0) or (maxTamAuto < 1000) then
        maxTamAuto := 10000000;

    nomeAssinatura := sintAmbiente ('CARTAVOX', 'ASSINATURA');

    s := sintAmbiente ('CARTAVOX', 'COPIAENVIADAS');
    guardaEnviadas := copy (s, 1, 1) <> 'N';

    s := sintAmbiente ('CARTAVOX', 'PERGUNTAAOSAIR');
    if s = '' then
        begin
            perguntaAoSair := TRUE;
            strPCopy (sz, 'SIM');
            writePrivateProfileString('CARTAVOX', 'PERGUNTAAOSAIR',     sz, 'DOSVOX.INI');
        end
    else
    perguntaAoSair := upcase (s[1]) <> 'N';

    s := sintAmbiente ('CARTAVOX', 'PERGUNTAAOSAIRFOLHEAMENTO');
    if s = '' then
        begin
            perguntaAoSairFolheamento  := false;
            strPCopy (sz, 'NAO');
            writePrivateProfileString('CARTAVOX',
'PERGUNTAAOSAIRFOLHEAMENTO',     sz, 'DOSVOX.INI');
        end
    else
    perguntaAoSairFolheamento := upcase (s[1]) = 'S';

    s := sintAmbiente ('CARTAVOX', 'FALANOMEPRIMEIRO');
    if s = '' then
        begin
            FALANOMEPRIMEIRO := TRUE;
            strPCopy (sz, 'SIM');
            writePrivateProfileString('CARTAVOX', 'FALANOMEPRIMEIRO',     sz, 'DOSVOX.INI');
        end
    else
        FALANOMEPRIMEIRO := upcase (s[1]) <> 'N';

    s := sintAmbiente ('CARTAVOX', 'CABECALHORESUMIDO');
    if s = '' then
        begin
            cabecalhoResumido := FALSE;
            strPCopy (sz, 'NAO');
            writePrivateProfileString('CARTAVOX', 'CABECALHORESUMIDO',     sz, 'DOSVOX.INI');
        end
    else
        cabecalhoResumido := upcase (s[1]) = 'S';

    s := sintAmbiente ('CARTAVOX', 'ARMAZENASENHA');
    guardaSenha := copy (s, 1, 1) = 'S';

    s := sintAmbiente ('CARTAVOX', 'SCCVPop3');
    senhaSalvaPop3 := decodFraseMime64 (s);

    s := sintAmbiente ('CARTAVOX', 'SCCVSmtp');
    senhaSalvaSmtp := decodFraseMime64 (s);

    s := sintAmbiente ('CARTAVOX', 'SCCV');
    if  guardaSenha and (trim(s) <> '') then
        senhaSalva := decodFraseMime64 (s)
    else
        senhaSalva := '';

    s := sintAmbiente ('CARTAVOX', 'APLICARREGRAS');
    aplicRegras:= copy (s, 1, 1) = 'S';

    s := sintAmbiente ('CARTAVOX', 'INSERIRASSINATURA');
    inserirAssinatura:= copy (s, 1, 1) = 'S';

    s := sintAmbiente ('CARTAVOX', 'INSERIRCONFIRMACAOLEITURA');
    inserirConfRec := copy (s, 1, 1) = 'S';

    s := sintAmbiente ('CARTAVOX', 'TEMPOREMONITORAR');
    if s <> '' then
        val (s, tempoRemonitorar, erro);
    if (erro > 0) or (tempoRemonitorar < 5) then
        tempoRemonitorar := 60;

    s := sintAmbiente ('CARTAVOX', 'AVISANOVASNOMONITORAR');
    avisaNovasMonitorar := copy (s, 1, 1) = 'S';

    s := sintAmbiente ('CARTAVOX', 'RECEBERAUTONOMONITORAR');
    receberaAutMonitorar := copy (s, 1, 1) = 'S';

    s := sintAmbiente ('CARTAVOX', 'BIPANOSPEAKER');
    bipaNoSpeaker := copy (s, 1, 1) <> 'N';

    s := sintAmbiente ('CARTAVOX', 'CLEK');
    clek := copy (s, 1, 1) <> 'N';

    s := sintAmbiente ('CARTAVOX', 'ADICIONAORIGINAL');
    adicionaOriginal := copy (s, 1, 1) <> 'N';
    if s = '' then
        begin
            strPCopy (sz, 'NAO');
            writePrivateProfileString('CARTAVOX', 'ADICIONAORIGINAL', sz, 'DOSVOX.INI');
        end;

    s := sintAmbiente ('CARTAVOX', 'SMTPCOMSENHA');
    smtpComSenha := copy (s, 1, 1) = 'S';

    s := sintAmbiente ('CARTAVOX', 'SMTPCOMTLS');
    smtpComTLS := copy (s, 1, 1) = 'S';

    s := sintAmbiente ('CARTAVOX', 'PORTASMTP');
    erro := 1;
    if s <> '' then
        val (s, portaSMTP, erro);
    if erro <> 0 then
        if usaSSL and (not smtpComTLS) then portaSMTP := 465
                                       else portaSMTP := 25;
    str (portaSMTP, s);
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'PORTASMTP', sz, 'DOSVOX.INI');

    s := sintAmbiente ('CARTAVOX', 'PORTAPOP3');
    erro := 1;
    if s <> '' then
        val (s, portaPOP3, erro);
    if erro <> 0 then
        if usaSSL then portaPOP3 := 995
                  else portaPOP3 := 110;
    str (portaPOP3, s);
    strPCopy (sz, s);
    writePrivateProfileString('CARTAVOX', 'PORTAPOP3', sz, 'DOSVOX.INI');

    arqRespAut := sintAmbiente ('CARTAVOX', 'ARQRESPAUT');

    assRespAut := sintAmbiente ('CARTAVOX', 'ASSRESPAUT');

    s := sintAmbiente ('CARTAVOX', 'SIGRESPAUT');
    sigRespAut := copy (s, 1, 1) = 'S';

    s := sintAmbiente ('CARTAVOX', 'GRUPODECONTAS');
    grupoContas := copy (s, 1, 1) = 'S';
end;

{-------------------------------------------------------------}
{       seleo interativa
{-------------------------------------------------------------}

function selecInterativa: string;
var
    nomes: array [0..1000] of char;
    p: pchar;
    nnomes, tam: integer;
begin
    tam := getprivateProfileString (NIL, NIL, '', nomes, 1000, 'CARTAVOX.INI');
    p := nomes;
    if (tam >= 1) and (p^ = #$0) then p := p + 1;   {evita falha em cartavox.ini com erro}

    nnomes := 0;
    while p^ <> #$0 do
        begin
            nnomes := nnomes + 1;
            p := p + strlen(p) + 1;
        end;

    p := nomes;
    if (tam >= 1) and (p^ = #$0) then p := p + 1;

    popupMenuCria (wherex, wherey, 79-wherex, nnomes, MAGENTA);
    while p^ <> #$0 do
        begin
            popupMenuAdiciona ('', maiuscansi(strPas(p)));
            p := p + strlen(p) + 1;
        end;

    popupMenuOrdena;
    popupMenuSeleciona;
    selecInterativa := opcoesItemSelecionado;
    writeln (opcoesItemSelecionado);
end;

{--------------------------------------------------------}
{       guarda configurao
{--------------------------------------------------------}

procedure guardaConfig;
var
    nomeConfig: string;
    sz, szNomeConfig: array [0..144] of char;
    c: char;
    i: integer;

begin
    mensagem ('CTNOMCNF', 1);   {'Informe o nome da configurao (at 20 letras)'}
    nomeConfig := '';
    c := sintEditaCampo (nomeConfig, 1, wherey, 255, 80, true);
    writeln;
    if (c = BAIX) or (c = CIMA) then nomeConfig := selecInterativa;

    while (nomeConfig <> '') and (nomeConfig [1] = ' ') do
        delete (nomeConfig, 1, 1);
    if nomeConfig = '' then
        begin
            mensagem ('CTDESIST', 1); {'Desistiu'}
            exit;
        end;

    strPCopy (szNomeConfig, nomeConfig);
    writePrivateProfileString('CARTAVOX', 'CONFIGURACAO', szNomeConfig, 'DOSVOX.INI');
    nomeConfiguracao := nomeConfig;
    setWindowTitle ('CARTAVOX ' + nomeConfiguracao);
    criaPrefixoNomeArq;

    for i := 1 to numChaves do
        begin
            getPrivateProfileString('CARTAVOX',     tabChaves[i], '', sz, 144, 'DOSVOX.INI');
            writePrivateProfileString(sznomeConfig, tabChaves[i], sz, 'CARTAVOX.INI');
        end;

    mensagem ('CTOK', 2);    {'OK'}
end;

{--------------------------------------------------------}
{     recupera uma configurao no grupo de contas
{--------------------------------------------------------}

procedure recuperaConfigGrupoContas (contaGrupo: string);
var nomeConfig: string;
    sz, szNomeConfig: array [0..144] of char;
    n, erro: integer;
begin

    nomeConfig := contaGrupo;
    strPCopy (szNomeConfig, nomeConfig);

    n := getPrivateProfileString(szNomeConfig, 'SERVIDORSMTP', '', sz, 144, 'CARTAVOX.INI');
    if n <= 0 then
        begin
            mensagem ('CTCNFNAO', 1);   {'Configurao no achada'}
            exit;
        end;
    writePrivateProfileString('CARTAVOX', 'SERVIDORSMTP', sz, 'DOSVOX.INI');
    hostSMTP := strPas (sz);

    if (guardaSenha) and (trim(senhaSalvaPop3) <> '') then
        begin
            strPCopy (szNomeConfig, nomeConfiguracao);
            strPCopy (sz, codFraseMime64 (senhaSalvaPop3));
            writePrivateProfileString(sznomeConfig, 'SCCVPop3', sz, 'CARTAVOX.INI');
        end;

    if (guardaSenha) and (trim(senhaSalvaSmtp) <> '') then
        begin
            strPCopy (szNomeConfig, nomeConfiguracao);
            strPCopy (sz, codFraseMime64 (senhaSalvaSmtp));
            writePrivateProfileString(sznomeConfig, 'SCCV', sz, 'CARTAVOX.INI');
            writePrivateProfileString(sznomeConfig, 'SCCVSMTP', sz, 'CARTAVOX.INI');
        end;

    nomeConfiguracao := nomeConfig;
    strPCopy (szNomeConfig, nomeConfiguracao);

    writePrivateProfileString('CARTAVOX', 'CONFIGURACAO', szNomeConfig, 'DOSVOX.INI');
    setWindowTitle ('CARTAVOX ' + nomeConfiguracao);
    criaPrefixoNomeArq;

    getPrivateProfileString(szNomeConfig, 'SMTPCOMSENHA', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SMTPCOMSENHA',     sz, 'DOSVOX.INI');
    smtpComSenha := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'APLICARREGRAS', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'APLICARREGRAS',     sz, 'DOSVOX.INI');
    aplicRegras := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'INSERIRASSINATURA', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'INSERIRASSINATURA',     sz, 'DOSVOX.INI');
    inserirAssinatura := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'INSERIRCONFIRMACAOLEITURA', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'INSERIRCONFIRMACAOLEITURA',     sz, 'DOSVOX.INI');
inserirConfRec := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'TEMPOREMONITORAR', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'TEMPOREMONITORAR',     sz, 'DOSVOX.INI');
    val (strPas (sz), tempoRemonitorar, erro);
    if erro <> 0 then tempoRemonitorar := 60;

    getPrivateProfileString(szNomeConfig, 'AVISANOVASNOMONITORAR', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'AVISANOVASNOMONITORAR',     sz, 'DOSVOX.INI');
    avisaNovasMonitorar := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'RECEBERAUTONOMONITORAR', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'RECEBERAUTONOMONITORAR',     sz, 'DOSVOX.INI');
    receberaAutMonitorar :=  upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'SMTPCOMTLS', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SMTPCOMTLS',     sz, 'DOSVOX.INI');
    smtpComTLS := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'USASSL', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'USASSL',     sz, 'DOSVOX.INI');
    usaSSL := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'PORTASMTP', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'PORTASMTP',     sz, 'DOSVOX.INI');
    val (strPas (sz), portaSMTP, erro);
    if erro <> 0 then
        if usaSSL and (not smtpComTLS) then
            portaSMTP := 465
        else
            portaSMTP := 25;

    getPrivateProfileString(szNomeConfig, 'SERVIDORIMAP', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SERVIDORIMAP', sz, 'DOSVOX.INI');
    hostIMAP := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'SERVIDORPOP3', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SERVIDORPOP3', sz, 'DOSVOX.INI');
    hostPOP3 := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'PORTAPOP3', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'PORTAPOP3',     sz, 'DOSVOX.INI');
    val (strPas (sz), portaPOP3, erro);
    if erro <> 0 then
        if usaSSL then portaPOP3 := 995
                  else portaPOP3 := 110;

    getPrivateProfileString(szNomeConfig, 'NOMEUSUARIO', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'NOMEUSUARIO',  sz, 'DOSVOX.INI');
    nomeUsuario := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'ENDERRESPOSTA', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'ENDERRESPOSTA', sz, 'DOSVOX.INI');
    enderResposta := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'ENDERUSUARIO', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'ENDERUSUARIO', sz, 'DOSVOX.INI');
    enderUsuario := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'CONTAUSUARIO', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'CONTAUSUARIO', sz, 'DOSVOX.INI');
    contaUsuario := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'NOMEUSUARIO', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'NOMEUSUARIO', sz, 'DOSVOX.INI');
    nomeUsuario := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'DIRRECEBE', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'DIRRECEBE',    sz, 'DOSVOX.INI');
    dirRecebe := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'DIRENVIA', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'DIRENVIA',     sz, 'DOSVOX.INI');
    dirEnvia := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'DIRANEXO', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'DIRANEXO',     sz, 'DOSVOX.INI');
    dirAnexo := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'LIMITEAUTOREC', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'LIMITEAUTOREC',sz, 'DOSVOX.INI');
    val (strPas (sz), maxTamAuto, erro);
    if erro <> 0 then maxTamAuto := 1000000;

    getPrivateProfileString(szNomeConfig, 'ASSINATURA', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'ASSINATURA',     sz, 'DOSVOX.INI');
    nomeAssinatura := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'APELIDOS', '', sz, 144, 'CARTAVOX.INI');
    nomeArqApelidos := strPas (sz);
    if nomeArqApelidos = '' then
        nomeArqApelidos := sintAmbiente ('CARTAVOX', 'APELIDOS');
    if nomeArqApelidos = '' then
        nomeArqApelidos := '@\apelidos.ini';
    writePrivateProfileString('CARTAVOX', 'APELIDOS',     sz, 'DOSVOX.INI');

    getPrivateProfileString(szNomeConfig, 'COPIAENVIADAS', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'COPIAENVIADAS',     sz, 'DOSVOX.INI');
    guardaEnviadas := upcase(sz[0]) <> 'N';

    getPrivateProfileString(szNomeConfig, 'ARMAZENASENHA', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'ARMAZENASENHA',     sz, 'DOSVOX.INI');
    guardaSenha := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'SCCVPop3', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SCCVPop3',     sz, 'DOSVOX.INI');
    senhaSalvaPop3 := DecodFraseMime64 (strPas(sz));

    getPrivateProfileString(szNomeConfig, 'SCCVSMTP', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SCCV',     sz, 'DOSVOX.INI');
    senhaSalvaSmtp := DecodFraseMime64 (strPas(sz));
    writePrivateProfileString('CARTAVOX', 'SCCVSMTP',     sz, 'DOSVOX.INI');
    senhaSalvaSmtp := DecodFraseMime64 (strPas(sz));

    getPrivateProfileString(szNomeConfig, 'ARQRESPAUT', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'ARQRESPAUT',     sz, 'DOSVOX.INI');
    arqRespAut := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'ASSRESPAUT', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'ASSRESPAUT',     sz, 'DOSVOX.INI');
    assRespAut := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'SIGRESPAUT', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SIGRESPAUT',     sz, 'DOSVOX.INI');
    sigRespAut := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'GRUPODECONTAS', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'GRUPODECONTAS',     sz, 'DOSVOX.INI');
    grupoContas := upcase(sz[0]) = 'S';
end;

{--------------------------------------------------------}
{       recupera configurao
{--------------------------------------------------------}

procedure recuperaConfig;
var c: char;
    nomeConfig: string;
    sz, szNomeConfig: array [0..144] of char;
    n, erro: integer;
    dirOriginal, existeArroba: string;
    pnomeDir: array [0..255] of char;
    p: integer;
begin

    GetModuleFileName (0, pnomeDir, 255);
    dirOriginal := strPas (pnomeDir);
    while dirOriginal [length (dirOriginal)] <> '\' do
        delete (dirOriginal, length (dirOriginal), 1);

//    transmitirPreparadas; //Pergunta se transmite caso exista
    mensagem ('CTNOMCNF', 1);   {'Informe o nome da configurao (at 20 letras)'}
    nomeConfig := '';
    c := sintEditaCampo (nomeConfig, 1, wherey, 255, 80, true);
    writeln;
    if (c = BAIX) or (c = CIMA) then nomeConfig := selecInterativa;

    while (nomeConfig <> '') and (nomeConfig [1] = ' ') do
        delete (nomeConfig, 1, 1);
    if nomeConfig = '' then exit;
    strPCopy (szNomeConfig, nomeConfig);

    n := getPrivateProfileString(szNomeConfig, 'SERVIDORSMTP', '', sz, 144, 'CARTAVOX.INI');
    if n <= 0 then
        begin
            mensagem ('CTCNFNAO', 1);   {'Configurao no achada'}
            exit;
        end;
    writePrivateProfileString('CARTAVOX', 'SERVIDORSMTP', sz, 'DOSVOX.INI');
    hostSMTP := strPas (sz);

    if (guardaSenha) and (trim(senhaSalvaSmtp) <> '') then
        begin
            strPCopy (szNomeConfig, nomeConfiguracao);
            strPCopy (sz, codFraseMime64 (senhaSalvaSmtp));
            writePrivateProfileString(sznomeConfig, 'SCCV', sz, 'CARTAVOX.INI');
            writePrivateProfileString(sznomeConfig, 'SCCVSMTP', sz, 'CARTAVOX.INI');
        end;

    if (guardaSenha) and (trim(senhaSalvaPop3) <> '') then
        begin
            strPCopy (szNomeConfig, nomeConfiguracao);
            strPCopy (sz, codFraseMime64 (senhaSalvaPop3));
            writePrivateProfileString(sznomeConfig, 'SCCVPOP3', sz, 'CARTAVOX.INI');
        end;

    nomeConfiguracao := nomeConfig;
    strPCopy (szNomeConfig, nomeConfiguracao);

    writePrivateProfileString('CARTAVOX', 'CONFIGURACAO', szNomeConfig, 'DOSVOX.INI');
    setWindowTitle ('CARTAVOX ' + nomeConfiguracao);
    criaPrefixoNomeArq;

    getPrivateProfileString(szNomeConfig, 'SMTPCOMSENHA', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SMTPCOMSENHA',     sz, 'DOSVOX.INI');
    smtpComSenha := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'APLICARREGRAS', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'APLICARREGRAS',     sz, 'DOSVOX.INI');
    aplicRegras := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'INSERIRASSINATURA', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'INSERIRASSINATURA',     sz, 'DOSVOX.INI');
    inserirAssinatura := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'INSERIRCONFIRMACAOLEITURA', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'INSERIRCONFIRMACAOLEITURA',     sz, 'DOSVOX.INI');
inserirConfRec := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'TEMPOREMONITORAR', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'TEMPOREMONITORAR',     sz, 'DOSVOX.INI');
    val (strPas (sz), tempoRemonitorar, erro);
    if erro <> 0 then tempoRemonitorar := 60;

    getPrivateProfileString(szNomeConfig, 'AVISANOVASNOMONITORAR', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'AVISANOVASNOMONITORAR',     sz, 'DOSVOX.INI');
    avisaNovasMonitorar := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'RECEBERAUTONOMONITORAR', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'RECEBERAUTONOMONITORAR',     sz, 'DOSVOX.INI');
    receberaAutMonitorar :=  upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'SMTPCOMTLS', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SMTPCOMTLS',     sz, 'DOSVOX.INI');
    smtpComTLS := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'USASSL', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'USASSL',     sz, 'DOSVOX.INI');
    usaSSL := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'PORTASMTP', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'PORTASMTP',     sz, 'DOSVOX.INI');
    val (strPas (sz), portaSMTP, erro);
    if erro <> 0 then
        if usaSSL and (not smtpComTLS) then
            portaSMTP := 465
        else
            portaSMTP := 25;

    getPrivateProfileString(szNomeConfig, 'SERVIDORIMAP', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SERVIDORIMAP', sz, 'DOSVOX.INI');
    hostIMAP := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'SERVIDORPOP3', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SERVIDORPOP3', sz, 'DOSVOX.INI');
    hostPOP3 := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'PORTAPOP3', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'PORTAPOP3',     sz, 'DOSVOX.INI');
    val (strPas (sz), portaPOP3, erro);
    if erro <> 0 then
        if usaSSL then portaPOP3 := 995
                  else portaPOP3 := 110;

    getPrivateProfileString(szNomeConfig, 'NOMEUSUARIO', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'NOMEUSUARIO',  sz, 'DOSVOX.INI');
    nomeUsuario := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'ENDERRESPOSTA', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'ENDERRESPOSTA', sz, 'DOSVOX.INI');
    enderResposta := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'ENDERUSUARIO', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'ENDERUSUARIO', sz, 'DOSVOX.INI');
    enderUsuario := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'CONTAUSUARIO', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'CONTAUSUARIO', sz, 'DOSVOX.INI');
    contaUsuario := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'NOMEUSUARIO', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'NOMEUSUARIO', sz, 'DOSVOX.INI');
    nomeUsuario := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'DIRRECEBE', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'DIRRECEBE',    sz, 'DOSVOX.INI');
    dirRecebe := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'DIRENVIA', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'DIRENVIA',     sz, 'DOSVOX.INI');
    dirEnvia := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'DIRANEXO', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'DIRANEXO',     sz, 'DOSVOX.INI');
    dirAnexo := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'LIMITEAUTOREC', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'LIMITEAUTOREC',sz, 'DOSVOX.INI');
    val (strPas (sz), maxTamAuto, erro);
    if erro <> 0 then maxTamAuto := 1000000;

    getPrivateProfileString(szNomeConfig, 'ASSINATURA', '', sz, 144, 'CARTAVOX.INI');
    nomeAssinatura := strPas (sz);
    if (pos ('@', nomeAssinatura) <> 0) then
                existeArroba := copy (nomeAssinatura, 1, 1);
                if existeArroba <> '' then
                begin
            delete (nomeAssinatura, 1, pos ('\', nomeAssinatura));
                nomeAssinatura := dirOriginal + nomeassinatura;
            strPCopy (sz, nomeAssinatura);
    writePrivateProfileString('CARTAVOX', 'ASSINATURA',     sz, 'DOSVOX.INI');
                end
                else
            strPCopy (sz, nomeAssinatura);
    writePrivateProfileString('CARTAVOX', 'ASSINATURA',     sz, 'DOSVOX.INI');

    getPrivateProfileString(szNomeConfig, 'ARQBLOQUEADOS', '', sz, 144, 'CARTAVOX.INI');
    nomeArqSpams := strPas (sz);
    if nomeArqSpams = '' then
        nomeArqSpams := sintAmbiente ('CARTAVOX', 'ARQBLOQUEADOS');
    if nomeArqSpams = '' then
        nomeArqSpams := '@\apelidos.ini';
                             p := pos ('@\', nomeArqSpams );
                             if p <> 0 then
                                 begin
                                     delete (nomeArqSpams , p, 2);
                                     insert (dirOriginal, nomeArqSpams , p);
                                 end;
strPCopy (sz, nomeArqSpams);
    writePrivateProfileString('CARTAVOX', 'ARQBLOQUEADOS',     sz, 'DOSVOX.INI');
    writePrivateProfileString('MATASPAM', 'ARQBLOQUEADOS',     sz, 'DOSVOX.INI');

    getPrivateProfileString(szNomeConfig, 'APELIDOS', '', sz, 144, 'CARTAVOX.INI');
    nomeArqApelidos := strPas (sz);
    if nomeArqApelidos = '' then
        nomeArqApelidos := sintAmbiente ('CARTAVOX', 'APELIDOS');
    if nomeArqApelidos = '' then
        nomeArqApelidos := '@\apelidos.ini';
                             p := pos ('@\', nomeArqApelidos );
                             if p <> 0 then
                                 begin
                                     delete (nomeArqApelidos , p, 2);
                                     insert (dirOriginal, nomeArqApelidos , p);
                                 end;
strPCopy (sz, nomeArqApelidos);
    writePrivateProfileString('CARTAVOX', 'APELIDOS',     sz, 'DOSVOX.INI');

    getPrivateProfileString(szNomeConfig, 'COPIAENVIADAS', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'COPIAENVIADAS',     sz, 'DOSVOX.INI');
    guardaEnviadas := upcase(sz[0]) <> 'N';

    getPrivateProfileString(szNomeConfig, 'ARMAZENASENHA', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'ARMAZENASENHA',     sz, 'DOSVOX.INI');
    guardaSenha := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'SCCVSMTP', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SCCV',     sz, 'DOSVOX.INI');
    senhaSalvaSmtp := DecodFraseMime64 (strPas(sz));
    writePrivateProfileString('CARTAVOX', 'SCCVSMTP',     sz, 'DOSVOX.INI');
    senhaSalvaSmtp := DecodFraseMime64 (strPas(sz));

    getPrivateProfileString(szNomeConfig, 'SCCVPOP3', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SCCVPOP3',     sz, 'DOSVOX.INI');
    senhaSalvaPop3 := DecodFraseMime64 (strPas(sz));

    getPrivateProfileString(szNomeConfig, 'ARQRESPAUT', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'ARQRESPAUT',     sz, 'DOSVOX.INI');
    arqRespAut := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'ASSRESPAUT', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'ASSRESPAUT',     sz, 'DOSVOX.INI');
    assRespAut := strPas (sz);

    getPrivateProfileString(szNomeConfig, 'SIGRESPAUT', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'SIGRESPAUT',     sz, 'DOSVOX.INI');
    sigRespAut := upcase(sz[0]) = 'S';

    getPrivateProfileString(szNomeConfig, 'GRUPODECONTAS', '', sz, 144, 'CARTAVOX.INI');
    writePrivateProfileString('CARTAVOX', 'GRUPODECONTAS',     sz, 'DOSVOX.INI');
    grupoContas := upcase(sz[0]) = 'S';
end;

{-------------------------------------------------------------}
{       Remove a configurao do arquivo cartavox.ini
{-------------------------------------------------------------}

procedure removeConfiguracao;
var
    nomeConfig: string;
    szNomeConfig: array [0..144] of char;
    c, c2: char;
    i: integer;
begin
    mensagem ('CTCONFRM', 1);      {'Escolha com as setas a configurao a remover'}
    nomeConfig := '';
    c := sintEditaCampo (nomeConfig, 1, wherey, 255, 80, true);
    writeln;
    if (c = BAIX) or (c = CIMA) then nomeConfig := selecInterativa;

    while (nomeConfig <> '') and (nomeConfig [1] = ' ') do
        delete (nomeConfig, 1, 1);
    if nomeConfig = '' then
        begin
            mensagem ('CTDESIST', 1);
            exit;
        end;

    repeat
        mensagem ('CTCNFRMS', 0);    {'Confirma remoo da configurao '}
        sintWrite (nomeConfig);
        write ('? ');
        sintLeTecla (c, c2);
        writeln;
    until upcase(c) in ['S', 'N', ENTER, ESC];
    if upcase(c) <> 'S' then
        begin
            mensagem ('CTDESIST', 2);
            exit;
        end;

    strPCopy (szNomeConfig, nomeConfig);

    for i := 1 to numChaves do
        writePrivateProfileString(sznomeConfig, tabChaves[i], NIL, 'CARTAVOX.INI');

    writePrivateProfileString(sznomeConfig, NIL, NIL, 'CARTAVOX.INI');

    mensagem ('CTOKRM', 2);        {'Ok, removida'}
end;

{--------------------------------------------------------}
{                   cria nova configurao
{--------------------------------------------------------}

procedure novaConfiguracao;
var nome: string;
    secoes: array [0..1000] of char;
    valor: array [0..100] of char;
    v: string;

    p: pchar;
    n, i, x, nsecoes: integer;
    conta, email: string;
    provedor: array [0..100] of char;
    dirProg, arqModeloProvedor: string;

const
    modelo: pchar = 'modelo';

    function pegaDirProg: string;
    var dir: string;
        p: array [0..100] of char;
        pnomeDir: array [0..255] of char;
    begin
        getPrivateProfileString('CARTAVOX', 'ARQPROVEDOR', '',
            p, 100, 'dosvox.ini');
        dir := strPas(p);
        if dir = '' then
            begin
                GetModuleFileName (0, pnomeDir, 255);
                dir := strPas (pnomeDir);
                while dir [length (dir)] <> '\' do
                    delete (dir, length (dir), 1);
                result := dir;
            end;
    end;

begin
    clrscr;
    textBackground (BLUE);
    mensagem ('CTNOVCNF', 1);   {'Nova configurao do Cartavox')}
    textBackground (BLACK);
    writeln;

    dirProg := pegaDirProg;

    // macete usado para facilitar os testes
    // evitando que o diretrio de fontes seja registrado
    if ansiUpperCase (copy (dirProg, 10, 16)) = '\FONTES\CARTAVOX' then
        delete (dirProg, 10, 16);

    arqModeloProvedor := dirProg + 'provedor.ini';

    mensagem ('CTSETACO', 1);  {'Use as setas para escolher um dos correios abaixo'}

    getprivateProfileString (NIL, NIL, '', secoes, 1000, @arqModeloProvedor[1]);
    p := secoes;
    nsecoes := 0;
    while p^ <> #$0 do
        begin
            nsecoes := nsecoes + 1;
            p := p + strlen(p) + 1;
        end;

    p := secoes;
    popupMenuCria (1, wherey, 29, nsecoes+1, MAGENTA);
    while p^ <> #$0 do
        begin
            popupMenuAdiciona ('', strPas(p));
            p := p + strlen(p) + 1;
        end;

    popupMenuOrdena;
    n := popupMenuSeleciona;
    if n <= 0 then exit;

    p := secoes;
    for i := 2 to n do
        p := p + strlen(p) + 1;
    gotoxy (1, wherey-1);
    clreol;

    strCopy (provedor, p);
    sintwriteln (strPas(provedor));

    mensagem ('CTNOME', 1);  {'Informe seu nome:'}
    sintReadln (nome);
    if nome = '' then
        begin
            mensagem ('CTDESIST', 2);    {'Desistiu'}
            exit;
        end;
    writeln;

    mensagem ('CTSEUEML', 1);  {'Qual o seu email neste servidor?'}
    sintReadln (email);
    if email = '' then
        begin
            mensagem ('CTDESIST', 2);    {'Desistiu'}
            exit;
        end;
    conta := email;
    x := pos ('@', conta);
    if x <> 0 then
        delete (conta, x, 9999);

    // *** Atualiza o Dosvox.ini com o MODELO do provedor.ini ***
    getprivateProfileString (modelo, NIL, '', secoes, 1000, @arqModeloProvedor[1]);
    p := secoes;
    while p^ <> #$0 do
        begin
            getprivateProfileString (modelo, p, '', valor, 1000, @arqModeloProvedor[1]);
            v := strPas(valor);
            if copy (v, 1, 2) = '@\' then
                 begin
                     delete (v, 1, 2);
                     insert (dirProg, v, 1);
                 end
            else
            if copy (v, 1, 3) = '"@\' then
                 begin
                     delete (v, 2, 2);
                     insert (dirProg, v, 2);
                 end;

            strPCopy (valor, v);
            WritePrivateProfileString('CARTAVOX', p, valor, 'dosvox.ini');
            p := p + strlen(p) + 1;
        end;

    getprivateProfileString (provedor, NIL, '', secoes, 1000, @arqModeloProvedor[1]);
    p := secoes;
    while p^ <> #$0 do
        begin
            getprivateProfileString (provedor, p, '', valor, 1000, @arqModeloProvedor[1]);

            v := strPas(valor);
            if copy (v, 1, 7) = '<conta>' then
                 begin
                     delete (v, 1, 7);
                     insert (conta, v, 1);
                 end
            else
            if copy (v, 1, 6) = '<nome>' then
                 begin
                     delete (v, 1, 6);
                     insert (nome, v, 1);
                 end;
            strPCopy (valor, v);

            WritePrivateProfileString('CARTAVOX', p, valor, 'dosvox.ini');
            p := p + strlen(p) + 1;
        end;

    pegaConfigInicial;   // a que acabou de gravar
    clreol;
end;

{--------------------------------------------------------}
{       seleciona a funo com as setas, opes de configurao
{--------------------------------------------------------}

function selSetasConfig: char;
var n: integer;
const
    tabLetrasConfig: string [8] = 'NCMGRAOP';

begin
    popupMenuCria (35, wherey, 44, 8, RED);
    MenuAdiciona ('CTAJCO00'); {'   N - Nova configurao'}
    MenuAdiciona ('CTAJCO01'); {'   C - Configurar'}
    MenuAdiciona ('CTAJCO01B'); {'    M - Configurar monitoramento'}
    MenuAdiciona ('CTAJCO02'); {'   G - Guardar configurao'}
    MenuAdiciona ('CTAJCO03'); {'   R - Recuperar configurao'}
    MenuAdiciona ('CTAJCO04'); {'    A - Apagar configurao'}
    MenuAdiciona ('CTAJCO05'); {'    O - Outras configuraes'}
    MenuAdiciona ('CTAJCO06'); {'    P - Painel de configurao'}

    n := popupMenuSeleciona;

    if (n > 0) and (n <=8) then
        selSetasConfig := tabLetrasConfig[n]
    else
        selSetasConfig := ESC;
end;

{--------------------------------------------------------}
{       ajuda das opes de configurao
{--------------------------------------------------------}

procedure ajudaConfig;
begin
    writeln;
    if not keypressed then
        mensagem ('CTAJUD01', 2); {'As opes so'}
    if not keypressed then
        mensagem ('CTAJCO00', 1); {'    N - Nova configurao'}
    if not keypressed then
        mensagem ('CTAJCO01', 1); {'    C - Configurar'}
    if not keypressed then
        mensagem ('CTAJCO01B', 1); {'    M - Configurar monitoramento'}
    if not keypressed then
        mensagem ('CTAJCO02', 1); {'    G - Guardar configurao'}
    if not keypressed then
        mensagem ('CTAJCO03', 1); {'    R - Recuperar   configurao'}
    if not keypressed then
        mensagem ('CTAJCO04', 1); {'    A - Apagar configurao'}
    if not keypressed then
        mensagem ('CTAJCO05', 1); {'    O - Outras configuraes'}
    if not keypressed then
        mensagem ('CTAJCO06', 1); {'    P - Painel de configurao'}
end;

{--------------------------------------------------------}
{       Opes de configurao
{--------------------------------------------------------}

procedure configurar;
var c, c2: char;
label inicioConfig;
begin
inicioConfig:
    telaPrincipal;
    textBackground (RED);
    mensagem ('CTCONFIG', 1);{'Configurao'}
    mensagem ('CTQUALOP', 0); {'Qual sua opo ? '}
    mensagem ('CTF1AJUD', 0); {'F1 ajuda '}
    sintLeTecla (c, c2);
    textBackground (BLACK);
    writeln;

    if (c = #0) and ((c2 = BAIX) or (c2 = CIMA)) then
        c := selSetasConfig
    else
    if c = #0 then
        begin
            ajudaConfig;
            goto inicioConfig;
        end;

    case upcase (c) of
        'R':  recuperaConfig;
        'C':  configuraTudo;
        'N':  novaConfiguracao;
        'G':  guardaConfig;
        'A':  removeConfiguracao;
        'M': configuraMonitoramento;
        'O': outrasConfiguracoes;
        'P': formConfig;
    else
        if c <> ESC then
            msgBaixo ('CTOPCINV')   {'Opo invlida'}
        else
            msgBaixo ('CTDESIST'); {'Desistiu'}
    end;
end;

{-------------------------------------------------------------}
begin
end.
