{-------------------------------------------------------------}
{
{           CartaVox - Resposta Automtica
{
{-------------------------------------------------------------}

unit carResp;

interface

uses
    dvArq,
    dvcrt,
    dvForm,
    dvWin,
    classes,
    sysUtils,
    windows,
    carDecod,
    carLeit,
    carMsg,
    carTela,
    carUtil,
    carVars,
    carEst,
    carSMTP;

procedure respostaAutomatica;
procedure ativaRespAut (preparar, ativar: boolean; nCar: integer);
procedure montaListaDeCartasRespAut;
function colocaRespostaCarta(nomeArq: string): string;
procedure criaListaCAR;
procedure destroiListaCAR;
procedure adicionaListaCAR (nome: string);
procedure excluirStrListaCAR (arquivoCAR: string);

implementation

uses
    carMonit,
    carEnvia;

var
    listaCAR: TStringList;
    dir: string;

{--------------------------------------------------------}
{  seleciona a funo com as setas, opes do menu
{  principal da resposta automtica
{--------------------------------------------------------}

function selSetasConfig: char;
var n: integer;
const
    tabLetrasConfig: string [2] = 'EA';

begin
    popupMenuCria (wherex, wherey, 50, 2, MAGENTA);
        MenuAdiciona ('CTAJRE01'); {'E - Escrever resposta automtica'}
        MenuAdiciona ('CTAJRE02'); {'A - Ativar resposta automtica de frias'}

    n := popupMenuSeleciona;
    if n > 0 then
        selSetasConfig := tabLetrasConfig[n]
    else
        selSetasConfig := ESC;
end;

{--------------------------------------------------------}
{  seleciona a funo com as setas, opes de edio
{  da resposta automtica
{--------------------------------------------------------}

function selSetasConfigEdicao: char;
var n: integer;
const
    tabLetrasConfig: string [2] = 'AC';

begin
    popupMenuCria (wherex, wherey, 50, 2, MAGENTA);
        MenuAdiciona ('CTAJRE03'); {'A - Editar assunto da resposta automtica'}
        MenuAdiciona ('CTAJRE04'); {'C - Editar corpo da resposta automtica'}

    n := popupMenuSeleciona;
    if n > 0 then
        selSetasConfigEdicao := tabLetrasConfig[n]
    else
        selSetasConfigEdicao := ESC;
end;

{--------------------------------------------------------}
{  cria arquivo de controle da resposta automtica
{  e escreve as informaes necessrias nele
{--------------------------------------------------------}

function escreveArquivo (nomeArq, assunto, respAssinatura: string): string;
var
    arquivoDestino, arquivoOrigem: TextFile;
    nomeArqRespAut, s: string;
    sz, szConfig: array [0..144] of char;
    cont: integer;

begin
    if arqRespAut = '' then
        begin
            if not fileExists(dirRecebe + '\' + 'respAut.txt') then
                nomeArqRespAut := dirRecebe + '\' + 'respAut.txt'
            else
                begin
                    cont := 1;
                    while fileExists(dirRecebe + '\' + 'respAut' + IntToStr(cont) + '.txt') do
                        cont := cont + 1;
                    nomeArqRespAut := dirRecebe + '\' + 'respAut' + IntToStr(cont) + '.txt';
                end;
        end
    else
        nomeArqRespAut := arqRespAut;

    AssignFile(arquivoDestino, nomeArqRespAut);
    try
        ReWrite(arquivoDestino);
    except
    on E : Exception do
        begin
            mensagem ('CTERRDSK', 1); {'Erro de escrita no disco'}
            escreveArquivo := 'erro';
            exit;
        end;
    end;
    AssignFile(arquivoOrigem, nomeArq);
    try
        Reset(arquivoOrigem);
    except
    on E : Exception do
        begin
            mensagem ('CTERRLEI', 1);  {'Erro de leitura do arquivo'}
            escreveArquivo := 'erro';
            exit;
        end;
    end;

    while not eof (arquivoOrigem) do
        begin
            try
                readln (arquivoOrigem, s);
            except
            on E : Exception do
                begin
                    mensagem ('CTERRLEI', 1);  {'Erro de leitura do arquivo'}
                    escreveArquivo := 'erro';
                    exit;
                end;
            end;
            try
                writeln (arquivoDestino, s);
            except
            on E : Exception do
                begin
            mensagem ('CTERRDSK', 1); {'Erro de escrita no disco'}
                    escreveArquivo := 'erro';
                    exit;
                end;
            end;
        end;
    try
        CloseFile(arquivoDestino);
    except
    on E : Exception do
        begin
            mensagem ('CTERFECH', 1); {'Erro ao fechar o arquivo'}
            escreveArquivo := 'erro';
            exit;
        end;
    end;
    try
        CloseFile(arquivoOrigem);
    except
    on E : Exception do
        begin
            mensagem ('CTERFECH', 1); {'Erro ao fechar o arquivo'}
            escreveArquivo := 'erro';
            exit;
        end;
    end;

    try
        if arqRespAut = '' then arqRespAut := nomeArqRespAut;
        strPCopy (sz, nomeArqRespAut);
        writePrivateProfileString('CARTAVOX', 'ARQRESPAUT', sz, 'DOSVOX.INI');
        strPCopy (szConfig, nomeConfiguracao);
        writePrivateProfileString(szConfig, 'ARQRESPAUT', sz, 'CARTAVOX.INI');

        assRespAut := assunto;
        strPCopy (sz, assunto);
        writePrivateProfileString('CARTAVOX', 'ASSRESPAUT', sz, 'DOSVOX.INI');
        strPCopy (szConfig, nomeConfiguracao);
        writePrivateProfileString(szConfig, 'ASSRESPAUT', sz, 'CARTAVOX.INI');

        sigRespAut := copy (respAssinatura, 1, 1) = 'S';
        strPCopy (sz, respAssinatura);
        writePrivateProfileString('CARTAVOX', 'SIGRESPAUT', sz, 'DOSVOX.INI');
        strPCopy (szConfig, nomeConfiguracao);
        writePrivateProfileString(szConfig, 'SIGRESPAUT', sz, 'CARTAVOX.INI');
    except
    on E : Exception do
        begin
            mensagem ('CTERRDSK', 1); {'Erro de escrita no disco'}
            escreveArquivo := 'erro';
            exit;
        end;
    end;

    escreveArquivo := 'ok';
end;

{--------------------------------------------------------}
{  pergunta se adiciona a assinatura na resposta automtica
{--------------------------------------------------------}

function perguntaAssinatura: string;
var
    resp: char;

begin
    if nomeAssinatura <> '' then
        begin
            repeat
                textBackGround (MAGENTA);
                mensagem ('CTADIASS', 0);   {'Adiciona sua assinatura ? '}
                textBackGround (BLACK);
                resp := sintReadkey;
                writeln (resp);
            until upcase (resp) in ['S', 'N', ENTER, ESC];
            if upcase (resp) = 'N' then
                begin
                    perguntaAssinatura := 'NAO';
                    exit;
                end;
            if resp = ESC then
                begin
                    perguntaAssinatura := 'cancelar';
                    exit;
            end;
            perguntaAssinatura := 'SIM';
        end
    else
        perguntaAssinatura := 'NAO';
end;

{--------------------------------------------------------}
{  obtm o assunto da resposta automtica para a criao de
{  uma nova resposta automtica
{--------------------------------------------------------}

function editaAssunto (var c: char): string;
var s: string;
begin
    s:= '';
    repeat
        textBackground (BLACK);
        mensagem ('CTQASSRE', 1); {'Qual o assunto da resposta automtica?'}
        c := sintEditaCampo (s, 1, wherey, 255, 80, true);
        writeln;
    until c in [ENTER, ESC];
    if c = ESC then
        editaAssunto := ''
    else
        editaAssunto := s;
end;

{--------------------------------------------------------}
{  pergunta se o usurio deseja ativar a resposta automtica,
{  se sim, ativa
{--------------------------------------------------------}

procedure escreveRespAtivar;
var
    c, c2: char;

begin
    repeat
        textBackground (BLACK);
        mensagem ('CTATREAU', 1); {'Deseja ativar a resposta automtica de frias?'}
        sintLeTecla (c, c2);
        writeln;
    until upcase (c) in ['S', 'N', ENTER, ESC];
sintclek;
    if upcase (c) in ['N', ESC] then
        mensagem ('CTREAUNA', 1) {'Resposta automtica de frias no foi ativada'}
    else
        begin
            monitorarRespAut;
            mensagem ('CTREAUDE', 1); {'Resposta automtica de frias desativada'}
        end;
    destroiListaCAR;
    destroiListaCPR;
end;

{--------------------------------------------------------}
{       retorna a data de criao do arquivo passado
{--------------------------------------------------------}

function pegaDatArq (nome: string): integer;
var
    data: Integer;

begin
    data := FileAge(nome);
    pegaDatArq := data;
end;

{--------------------------------------------------------}
{   cria lista com nome dos arquivos CAR das cartas
{   selecionadas para enviar a resposta automtica
{--------------------------------------------------------}

procedure criaListaCAR;
begin
    if (listaCAR = nil) then
        listaCAR := TStringList.create;
end;

{--------------------------------------------------------}
{       destri a lista com nome dos arquivos temporrios
{--------------------------------------------------------}

procedure destroiListaCAR;
begin
    if listaCAR <> nil then
        begin
            listaCAR.free;
            listaCAR := nil;
        end;
end;

{--------------------------------------------------------}
{   adiciona o nome da carta na lista com nome das cartas
{--------------------------------------------------------}

procedure adicionaListaCAR (nome: string);
begin
    if listaCAR <> nil then listaCAR.add (nome);
end;

{--------------------------------------------------------}
{   adiciona o nome da carta na lista com nome das cartas
{--------------------------------------------------------}

procedure excluirStrListaCAR (arquivoCAR: string);
var
    indice: integer;

begin
    if (listaCAR <> nil) then
        begin
            indice := listaCAR.indexOf (arquivoCAR);
            if indice <> -1 then listaCAR.delete (indice);
        end;
end;

{--------------------------------------------------------}
{    monta lista de cartas que sero enviadas resposta
{    automtica
{--------------------------------------------------------}

procedure montaListaDeCartasRespAut;
var
    indice: integer;
    nomeArq: string;

begin
    numRegsRespAut := 0;

    for indice := 0 to listaCAR.count - 1 do
        begin
            nomeArq := listaCAR.strings [indice];

            numRegsRespAut := numRegsRespAut + 1;
            regLidoRespAut [numRegsRespAut] := inicializaPEstrutura;
            regLidoRespAut [numRegsRespAut]^.carta := inicializaPCarta;
            regLidoRespAut [numRegsRespAut]^.carta^.nomArqCarta := nomeArq;
            regLidoRespAut [numRegsRespAut]^.carta^.dataHora := pegaDatArq (nomeArq);
            regLidoRespAut [numRegsRespAut]^.carta^.tamanho :=
pegaTamanhoArq (nomeArq);
        end;
end;

{-------------------------------------------------------------}
{       Confirma o destino da carta
{-------------------------------------------------------------}

function confirmaDestino (nomeDest:string): boolean;
var c, c2: char;
begin
    confirmaDestino := true;
    repeat
        textBackground (MAGENTA);
        mensagem ('CTPPREAU', 0); {'Preparando resposta automtica para '}
        sintWriteln (nomeDest);
        textBackground (BLACK);
        clreol;
        mensagem ('CTCNFDST', 0);  {'Confirma destino {s/n) ? '}
        sintLeTecla (c, c2);
        writeln;
    until upcase (c) in ['S', 'N', ENTER, ESC];
    if upcase (c) in ['N', ESC] then
        confirmaDestino := false;
end;

{--------------------------------------------------------}
{  Prepara e transmite a resposta automtica para as
{  cartas do folheamento
{--------------------------------------------------------}

procedure preparaRespAut (nCar: integer);
var
    c, c2: char;
    i, numRegsAux: integer;
    enviarSelecionado: boolean;
    nomeDest, nomArqCar: string;
label esperaResp;

begin
    enviarSelecionado := false;
    if temItemSelecionado then
        begin
            repeat
                mensagem ('CTREAUSE', 1); {'Deseja preparar resposta automtica para as selecionadas?'}
                mensagem ('CTINFSEL', 1);{'Tecle c para conhecer as selecionadas.'}
esperaResp:
                sintLeTecla (c, c2);
            until upcase (c) in ['S', 'N', 'C', ENTER, ESC];
            if upcase(c) in [ESC, 'N'] then
                begin
                    msgBaixo ('CTDESIST');  {'Desistiu'}
                    exit;
                end;
            if upcase(c) = 'C' then
                begin
                    for i := 1 to numRegs do
                        if regLido [i]^.selecionado then
                            begin
                                mensagem ('CTCARTA', 0); {'Carta'}
                                write (' ');
                                sintWriteInt (i);
                                writeln;
                                mensagem ('CTENVPOR', 0); {'Enviada por '}
begin
    if trim (regLido [nCar]^.carta^.x_original_from) <> '' then
                                sintWriteln ( regLido [i]^.carta^.x_original_from)
else
                                sintWriteln ( regLido [i]^.carta^.from);
end;
                                mensagem ('CTASSUNT', 0); {'Assunto: '}
                                sintWriteln (regLido[i]^.carta^.subject);
                            end;
                    goto esperaResp;
                end;
            enviarSelecionado := upcase (c) in ['S', ENTER];
        end;

    if not enviarSelecionado then
        begin
begin
    if trim (regLido [nCar]^.carta^.x_original_from) <> '' then
            nomeDest := regLido [nCar]^.carta^.x_original_from
else
            nomeDest := regLido [nCar]^.carta^.from;
end;
            if confirmaDestino (nomeDest) then
                c := 'S'
            else
                c := 'N';
            if upcase(c) <> 'S' then
                begin
                    msgBaixo ('CTDESIST');  {'Desistiu'}
                    exit;
                end
            else
                begin
                    criaListaCAR;
                    nomArqCar := dirRecebe + '\' + regLido[nCar]^.carta^.nomArqCarta;
                    adicionaListaCAR (nomArqCar);
                    prepararCartaRespAut (1, false);
                    msgBaixo ('CTCARPRP');  {'Carta preparada para envio'}
                end;
        end
    else
        begin
            criaListaCAR;
            numRegsAux := numRegs;
            for i := 1 to numRegsAux do
                if regLido [i]^.selecionado then
                    begin
                        nomArqCar := dirRecebe + '\' + regLido[i]^.carta^.nomArqCarta;
                        adicionaListaCAR (nomArqCar);
                    end;
            prepararCartaRespAut (totalDeItensSelecionados, false);
            mensagem ('CTCARPRS', 1); {'Cartas preparadas para envio'}
        end;
    destroiListaCAR;
end;

{--------------------------------------------------------}
{  pergunta ao usurio o assunto e o texto da resposta automtica
{  para a criao de uma nova resposta automtica e chama a funo
{  'escreveArquivo' para criar o arquivo de controle que guarda
{  estas informaes
{--------------------------------------------------------}

function perguntaNovaResp: string;
var
    c, c2: char;
    assunto, nomeArq, res, respAssinatura, dirAtual: string;
    editar: boolean;
begin
    assunto := editaAssunto(c);
    if c = ESC then
        begin
            perguntaNovaResp := 'desistiu';
            exit;
        end;

    dir := ExtractFilePath(ParamStr(0));
    Delete(dir, Length(dir), 1);
    getDir (0, dirAtual);
    {$I-}  chdir (dir);  {$I+}
    if ioresult <> 0 then ;
    nomeArq := escolheNomeArq (editar, dir);
    {$I-}  chdir (dirAtual);  {$I+}
    if ioresult <> 0 then ;

    if trim (nomeArq) = '' then
        begin
            perguntaNovaResp := 'desistiu';
            exit;
        end;

    if editar then
        begin
            mensagem ('CTABREDI', 1);  {'Abrindo editor'}
            editaArquivo (nomeArq);
            limpaBufTec;
            sintBip;
        end;

    repeat
        respAssinatura := perguntaAssinatura;
        if respAssinatura = 'cancelar' then
            begin
                repeat
                    mensagem ('CTCAREAU', 1); {'Deseja realmente cancelar o preparo da resposta automtica?'}
                    sintLeTecla (c, c2);
                until upcase (c) in ['S', 'N', ENTER, ESC];
                if upcase (c) in ['S', ENTER] then
                    begin
                        perguntaNovaResp := 'desistiu';
                        exit;
                    end;
            end;
    until respAssinatura <> 'cancelar';

    res := escreveArquivo(nomeArq, assunto, respAssinatura);
    if res = 'erro' then
        begin
            perguntaNovaResp := 'erro';
            exit;
        end;

    perguntaNovaResp := 'ok';

end;

{--------------------------------------------------------}
{  edita o texto da resposta automtica e grava ele no arquivo
{  de controle da resposta automtica
{--------------------------------------------------------}

function perguntaEditaTextoRespAut: string;
var
    sz, szConfig: array [0..144] of char;
    respAssinatura: string;
    c, c2: char;

begin

    // Abre o arquivo temporrio para edio
    mensagem ('CTABREDI', 1);  {'Abrindo editor'}
    editaArquivo (arqRespAut);
    limpaBufTec;
    sintBip;

    // Pergunta se o usurio quer a assinatura
    repeat
        respAssinatura := perguntaAssinatura;
        if respAssinatura = 'cancelar' then
            begin
                repeat
                    mensagem ('CTCAESED', 1); {'Deseja realmente cancelar esta edio?'}
                    sintLeTecla (c, c2);
                until upcase (c) in ['S', 'N', ENTER, ESC];
                if upcase (c) in ['S', ENTER] then
                    begin
                        perguntaEditaTextoRespAut := 'desistiu';
                        exit;
                    end;
            end;
    until respAssinatura <> 'cancelar';

    try
        sigRespAut := copy (respAssinatura, 1, 1) = 'S';
        strPCopy (sz, respAssinatura);
        writePrivateProfileString('CARTAVOX', 'SIGRESPAUT', sz, 'DOSVOX.INI');
        strPCopy (szConfig, nomeConfiguracao);
        writePrivateProfileString(szConfig, 'SIGRESPAUT', sz, 'CARTAVOX.INI');
    except
    on E : Exception do
        begin
            mensagem ('CTERRDSK', 1); {'Erro de escrita no disco'}
            perguntaEditaTextoRespAut := 'erro';
            exit;
        end;
    end;

    msgBaixo ('CTOK'); {'OK'}
    perguntaEditaTextoRespAut := 'ok';
end;

{--------------------------------------------------------}
{  edita o assunto da resposta automtica e grava ele no
{  arquivo de controle da resposta automtica
{--------------------------------------------------------}

function perguntaEditaAssuntoRespAut: string;
var
    assunto: string;
    c: char;
    sz: array [0..144] of char;

begin
    assunto := trim(assRespAut);
    repeat
        textBackground (BLACK);
        mensagem ('CTEASSUN', 1); {'Editore o assunto da carta'}
        sintetiza (assunto);
        c := sintEditaCampo (assunto, 1, wherey, 255, 80, true);
        writeln;
    until c in [ENTER, ESC];
    if c = ESC then
        perguntaEditaAssuntoRespAut := 'desistiu'
    else
        begin
            try
                assRespAut := assunto;
                strPCopy (sz, assunto);
                writePrivateProfileString('CARTAVOX', 'ASSRESPAUT', sz, 'DOSVOX.INI');
                msgBaixo ('CTOK'); {'OK'}
                perguntaEditaAssuntoRespAut := 'ok';
            except
            on E : Exception do
                begin
                    mensagem ('CTERRDSK', 1); {'Erro de escrita no disco'}
                    perguntaEditaAssuntoRespAut := 'erro';
                    exit;
                end;
            end;
        end;
end;

{-------------------------------------------------------------}
{     Coloca a resposta na carta da resposta automtica
{-------------------------------------------------------------}

function colocaRespostaCarta(nomeArq: string): string;
var i, tam: integer;
    arquivoDestino, arquivoOrigem: TextFile;
    vetorMsg : TStringList;
    s, arquivoTemp, nomeArqRespAut: string;

    procedure erro (e: string);
    begin
        mensagem (e, 1); {'Erro ...'}
        vetorMsg.free;
    end;

begin
    colocaRespostaCarta := 'erro';
    vetorMsg := TStringList.Create;

    //nomeArqRespAut recebe o nome do arquivo da resposta automtica
    if arqRespAut <> '' then
        nomeArqRespAut := arqRespAut
    else
        begin
            erro ('CTERESPA');   {'Erro no arquivo da resposta automtica'}
            exit;
        end;

    arquivoTemp := anexaAssinaturaRespAut (nomeArqRespAut, false);

    AssignFile(arquivoOrigem, nomeArq);
    try
        Reset(arquivoOrigem);
    except
    on E : Exception do
         begin
             erro ('CTERRLEI');  {'Erro de leitura do arquivo'}
             exit;
         end;
    end;
    i := 0;
    while not eof (arquivoOrigem) do
        begin
            try
                readln (arquivoOrigem, s);
                except
                on E : Exception do
                begin
                    erro ('CTERRLEI');  {'Erro de leitura do arquivo'}
                    exit;
                end;
            end;
            vetorMsg.add (s);
            i := i + 1;
        end;
    tam := i;
    try
        CloseFile(arquivoOrigem);
    except
    on E : Exception do
         begin
            erro ('CTERFECH');  {'Erro ao fechar o arquivo'}
            exit;
         end;
    end;

    AssignFile(arquivoOrigem, arquivoTemp);
    try
        Reset(arquivoOrigem);
    except
    on E : Exception do
         begin
             erro ('CTERRLEI');  {'Erro de leitura do arquivo'}
             exit;
         end;
    end;
    AssignFile(arquivoDestino, nomeArq);
    try
        Rewrite(arquivoDestino);
    except
    on E : Exception do
         begin
             erro ('CTERRDSK'); {'Erro de escrita no disco'}
             exit;
         end;
    end;
    while not eof (arquivoOrigem) do
        begin
            try
                readln (arquivoOrigem, s);
                except
                on E : Exception do
                begin
                    erro ('CTERRLEI');  {'Erro de leitura do arquivo'}
                    exit;
                end;
            end;
            try
                writeln (arquivoDestino, s);
                except
                on E : Exception do
                begin
                    erro ('CTERRDSK');  {'Erro de escrita no disco'}
                    exit;
                end;
            end;
        end;
    try
        CloseFile(arquivoOrigem);
    except
    on E : Exception do
         begin
            erro ('CTERFECH');  {'Erro ao fechar o arquivo'}
            exit;
         end;
    end;

    if arquivoTemp <> nomeArqRespAut then DeleteFile(Pchar(arquivoTemp));

    for i := 0 to tam do
        begin
            try
                writeln(arquivoDestino, vetorMsg[i]);
                except
                on E : Exception do
                begin
                    erro ('CTERRDSK');  {'Erro de escrita no disco'}
                    exit;
                end;
            end;
        end;
    try
        CloseFile(arquivoDestino);
    except
    on E : Exception do
         begin
            erro ('CTERFECH');  {'Erro ao fechar o arquivo'}
            exit;
         end;
    end;

    vetorMsg.free;
    colocaRespostaCarta := nomeArq;
end;

{--------------------------------------------------------}
{       ajuda do menu principal da resposta automtica
{--------------------------------------------------------}

procedure ajudaConfig;
begin
    writeln;
    if not keypressed then
        mensagem ('CTAJUD01', 2); {'As opes so'}
    if not keypressed then
        mensagem ('CTAJRE01', 1);{'   E - Escrever Resposta automtica'}
    if not keypressed then
        mensagem ('CTAJRE02', 1);{'   A - Ativar Resposta automtica de frias'}
end;

{--------------------------------------------------------}
{       ajuda do menu de edio da resposta automtica
{--------------------------------------------------------}

procedure ajudaConfigEdicao;
begin
    writeln;
    textBackground (BLUE);
    mensagem ('CTAJUD01', 1); {'As opes so'}
    textBackground (BLACK);
    if not keypressed then
        mensagem ('CTAJRE03', 1);{'   A - Editar o assunto da resposta automtica'}
    if not keypressed then
        mensagem ('CTAJRE04', 1);{'   C - Editar o corpo da resposta automtica'}
end;

{--------------------------------------------------------}
{  escreve uma nova resposta automtica se ela ainda no foi escrita ou
{  entra no menu de edio se a resposta automtica j foi escrita.
{  No final chama a rotina para enviar resposta automtica
{--------------------------------------------------------}

procedure escreveRespAut (preparar, ativar: boolean; nCar: integer);
var
    c, c2: char;
    res: string;
    respEmBranco: boolean;
label desistiu, continuaMenu;

begin
    respEmBranco := false;

    if (arqRespAut = '') or (not fileExists (arqRespAut)) then respEmBranco := true;

    if respEmBranco = true then
        begin
            res := perguntaNovaResp;
            if res = 'desistiu' then goto desistiu
            else if res = 'erro' then exit;
            msgBaixo('CTREAUPP'); {'Resposta automtica preparada'}
            if preparar then preparaRespAut (nCar);
            if ativar then escreveRespAtivar;
        end
    else
        begin
            mensagem ('CTEXREAU', 2); {'J existe uma resposta automtica configurada.'}
continuaMenu:
            textBackground (BLACK);
            mensagem ('CTQUALOP', 0); {'Qual sua opo ? '}
            mensagem ('CTF1AJUD', 0); {'F1 ajuda '}
            sintLeTecla (c, c2);
            writeln;

            if c = #0 then
                if c2 = F1 then
                    begin
                        ajudaConfigEdicao;
                        goto continuaMenu;
                    end
                else if c2 in [BAIX, CIMA] then
                    c := selSetasConfigEdicao;

            case upcase (c) of
                'A': begin
                         res := perguntaEditaAssuntoRespAut;
                         if res = 'erro' then exit
                         else if res = 'desistiu' then goto desistiu;
                     end;
                'C': begin
                          res := perguntaEditaTextoRespAut;
                          if res = 'erro' then exit
                          else if res = 'desistiu' then goto desistiu;
                     end;
                #0, ENTER, ESC, 'N': goto desistiu;
           end;
        end;
        exit;

desistiu:
    mensagem ('CTDESIST', 1);   {'Desistiu...'}
end;

{--------------------------------------------------------}
{  se existe resposta automtica, pergunta se o usurio deseja
{  ativ-la ou envi-la, caso contrrio, pergunta se o usurio
{  deseja escrev-la
{--------------------------------------------------------}

procedure ativaRespAut (preparar, ativar: boolean; nCar: integer);
var
    respAutExiste: boolean;
    var c, c2: char;
label desistiu;
begin
    respAutExiste := false;

    if (arqRespAut <> '') and (fileExists (arqRespAut)) then respAutExiste := true;

    if respAutExiste = false then
        begin
            repeat
                textBackground (BLACK);
                mensagem ('CTMEAUNE', 1); {'A resposta automtica no foi escrita, deseja escrev-la agora?'}
                sintLeTecla (c, c2);
                writeln;
            until upcase (c) in ['S', 'N', ENTER, ESC];
            if upcase (c) in ['N', ESC] then goto desistiu
            else escreveRespAut (preparar, ativar, nCar);
            exit;
        end
    else
        begin
            if preparar then
                preparaRespAut (nCar)
            else
                escreveRespAtivar;
        end;
    exit;

desistiu:
    mensagem ('CTDESIST', 1);   {'Desistiu...'}

end;

{--------------------------------------------------------}
{       execuo do menu principal da resposta automtica
{--------------------------------------------------------}

procedure respostaAutomatica;
var c, c2: char;
label inicioResp;
begin
inicioResp:
    telaPrincipal;
    textBackground (BLUE);
    mensagem ('CTRESAUT', 1); {'Resposta automtica'}
    textBackground (BLACK);
    mensagem ('CTQUALOP', 0); {'Qual sua opo ? '}
    mensagem ('CTF1AJUD', 0); {'F1 ajuda '}
    sintLeTecla (c, c2);
    writeln;

    if (c = #0) and ((c2 = BAIX) or (c2 = CIMA)) then
        c := selSetasConfig
    else
    if c = #0 then
        begin
            ajudaConfig;
            goto inicioResp;
        end;

    case upcase (c) of
        'E':  escreveRespAut (false, false, 0);
        'A':  ativaRespAut (false, true, 0);
    else
        if c <> ESC then
            msgBaixo ('CTOPCINV')  {'Opo invlida'}
        else
            msgBaixo ('CTDESIST');  {'Desistiu'}
    end;

end;

end.
